==> haskell-stream-0.4.7.2-225.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-stream.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 Stream
version:              0.4.7.2
visibility:           public
id:                   Stream-0.4.7.2-DmwYFSw12YyFdx1G53U40z
key:                  Stream-0.4.7.2-DmwYFSw12YyFdx1G53U40z
license:              BSD-3-Clause
maintainer:           Wouter Swierstra <wouter.swierstra@gmail.com>
author:
    Wouter Swierstra <wouter.swierstra@gmail.com>
    Bas van Dijk <v.dijk.bas@gmail.com>

stability:            experimental
synopsis:             A library for manipulating infinite lists.
description:
    This package implements functions, analogous
    to those from Data.List, to create and manipulate
    infinite lists: @data Stream a = Cons a (Stream a)@.
    It provides alternative definitions for those
    Prelude functions that make sense for such streams.
    Note that this package has (almost)
    nothing to do with the work on /Stream Fusion/ by
    Duncan Coutts, Roman Leshchinskiy, and Don Stewart.

category:             Data
abi:                  b3a3d8f01c395d160529707ac0e9389d
exposed:              True
exposed-modules:      Data.Stream
import-dirs:          /usr/lib/ghc-9.6.6/site-local/Stream-0.4.7.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/Stream-0.4.7.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/Stream-0.4.7.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-stream
hs-libraries:         HSStream-0.4.7.2-DmwYFSw12YyFdx1G53U40z
depends:
    QuickCheck-2.15.0.1-DMgRmI5QzBCFdvvi5liF0L base-4.18.2.1
    lazysmallcheck-0.6-IWk82oVJh1K3AL7UYRy21R

haddock-interfaces:   /usr/share/doc/haskell-stream/html/Stream.haddock
haddock-html:         /usr/share/doc/haskell-stream/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-stream-0.4.7.2-226-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-stream.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 Stream
version:              0.4.7.2
visibility:           public
id:                   Stream-0.4.7.2-DB2VoDkLn8TIMGdmByRjYh
key:                  Stream-0.4.7.2-DB2VoDkLn8TIMGdmByRjYh
license:              BSD-3-Clause
maintainer:           Wouter Swierstra <wouter.swierstra@gmail.com>
author:
    Wouter Swierstra <wouter.swierstra@gmail.com>
    Bas van Dijk <v.dijk.bas@gmail.com>

stability:            experimental
synopsis:             A library for manipulating infinite lists.
description:
    This package implements functions, analogous
    to those from Data.List, to create and manipulate
    infinite lists: @data Stream a = Cons a (Stream a)@.
    It provides alternative definitions for those
    Prelude functions that make sense for such streams.
    Note that this package has (almost)
    nothing to do with the work on /Stream Fusion/ by
    Duncan Coutts, Roman Leshchinskiy, and Don Stewart.

category:             Data
abi:                  f055bcfc22d24671d9de44e84228da98
exposed:              True
exposed-modules:      Data.Stream
import-dirs:          /usr/lib/ghc-9.6.6/site-local/Stream-0.4.7.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/Stream-0.4.7.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/Stream-0.4.7.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-stream
hs-libraries:         HSStream-0.4.7.2-DB2VoDkLn8TIMGdmByRjYh
depends:
    QuickCheck-2.15.0.1-1xFq7rzYyJMIIsLto0YgsS base-4.18.2.1
    lazysmallcheck-0.6-IWk82oVJh1K3AL7UYRy21R

haddock-interfaces:   /usr/share/doc/haskell-stream/html/Stream.haddock
haddock-html:         /usr/share/doc/haskell-stream/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
